{pkgs', ...}: let
  packageData = builtins.fromJSON (builtins.readFile ../../package.json);
  version = packageData.version;
  lib = pkgs'.lib;
in
  pkgs'.writeShellScriptBin "update-web-test" ''
    source ${pkgs'.common}/bin/common

    echo_section "Checking code"
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    echo_step "Running prettier"

    PROJECT_ROOT="$(pwd)"
    TEST_PATH="''${PROJECT_ROOT}/test/"
    TEST_CASES_PATH="''${TEST_PATH}cases/"
    TEST_WEB_PATH="''${TEST_PATH}web/"
    SOURCE_PATH="''${PROJECT_ROOT}/source/"

    ${pkgs'.gnused}/bin/sed -i -E "s_(\"[0-9]+\.[0-9]+\.[0-9]+\")_\"${version}\"_g" "''${SOURCE_PATH}/types/version.mjs"
    ${pkgs'.gnused}/bin/sed -i -E "s_(\"[0-9]+\.[0-9]+\.[0-9]+\")_\"${version}\"_g" "''${TEST_CASES_PATH}/monster.mjs"

    ${pkgs'.findutils}/bin/find ''${TEST_CASES_PATH} -type f | sed "s|^$TEST_CASES_PATH||" > ''${TEST_WEB_PATH}/import.js
    ${pkgs'.gnused}/bin/sed -i 's|^|import "../cases/|' ''${TEST_WEB_PATH}/import.js
    ${pkgs'.gnused}/bin/sed -i 's|$|";|' ''${TEST_WEB_PATH}/import.js
    ${pkgs'.gnused}/bin/sed -i "1 i import \"./prepare.js\";" ''${TEST_WEB_PATH}/import.js
    ${pkgs'.gnused}/bin/sed -i "1 i /** this file was created automatically by the run-web-tests script */" ''${TEST_WEB_PATH}/import.js

    if ! ${pkgs'.projectNodeJS}/bin/npx esbuild --platform=browser --sourcemap=inline --external:ws \
             --external:jsdom --external:fs --external:process --external:crypto --bundle ''${TEST_WEB_PATH}/import.js --outfile=''${TEST_WEB_PATH}/tests.js
    then
      echo "ERROR: esbuild failed, check your JS!"
      exit 1
    fi

    ${pkgs'.gnused}/bin/sed -i '1s/^/try {\n/' ''${TEST_PATH}web/tests.js
    echo "} catch (e) {" >> ''${TEST_PATH}web/tests.js
    echo "document.getElementById('mocha-errors').insertAdjacentHTML('afterbegin', e );" >> ''${TEST_WEB_PATH}/tests.js
    echo "document.getElementById('mocha-stats').style.backgroundColor = 'red';" >> ''${TEST_WEB_PATH}/tests.js
    echo "}" >> ''${TEST_WEB_PATH}/tests.js

    ${pkgs'.gnused}/bin/sed -i -E "/<h1/s_.*_  <h1 style='margin-bottom: 0.1em;'>Monster ${version}</h1>_" ''${TEST_WEB_PATH}/test.html
    ${pkgs'.gnused}/bin/sed -i -E "/id=\"lastupdate\"/s_.*_  <div id=\"lastupdate\" style='font-size:0.7em'>last update $(date)</div>_" ''${TEST_WEB_PATH}/test.html
    ${pkgs'.gnused}/bin/sed -i -E "s_src=\"([\"]*)\.js.*\"_src=\"\1.js?r=$(date +"%T")\"_" ''${TEST_WEB_PATH}/test.html

    echo_ok "Webtest is updated"


  ''
